<?php

/**
 * Copyright Guillaume Bourgeois (2018)
 *
 * contact@souke.fr
 *
 * Ce logiciel est un programme informatique servant à aider les producteurs
 * à distribuer leur production en circuits courts.
 *
 * Ce logiciel est régi par la licence CeCILL soumise au droit français et
 * respectant les principes de diffusion des logiciels libres. Vous pouvez
 * utiliser, modifier et/ou redistribuer ce programme sous les conditions
 * de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA
 * sur le site "http://www.cecill.info".
 *
 * En contrepartie de l'accessibilité au code source et des droits de copie,
 * de modification et de redistribution accordés par cette licence, il n'est
 * offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,
 * seule une responsabilité restreinte pèse sur l'auteur du programme,  le
 * titulaire des droits patrimoniaux et les concédants successifs.
 *
 * A cet égard  l'attention de l'utilisateur est attirée sur les risques
 * associés au chargement,  à l'utilisation,  à la modification et/ou au
 * développement et à la reproduction du logiciel par l'utilisateur étant
 * donné sa spécificité de logiciel libre, qui peut le rendre complexe à
 * manipuler et qui le réserve donc à des développeurs et des professionnels
 * avertis possédant  des  connaissances  informatiques approfondies.  Les
 * utilisateurs sont donc invités à charger  et  tester  l'adéquation  du
 * logiciel à leurs besoins dans des conditions permettant d'assurer la
 * sécurité de leurs systèmes et ou de leurs données et, plus généralement,
 * à l'utiliser et l'exploiter dans les mêmes conditions de sécurité.
 *
 * Le fait que vous puissiez accéder à cet en-tête signifie que vous avez
 * pris connaissance de la licence CeCILL, et que vous en avez accepté les
 * termes.
 */

use common\helpers\GlobalParam;
use domain\PointSale\UserPointSale\UserPointSale;
use domain\Producer\Producer\Producer;
use yii\grid\GridView;
use yii\helpers\Html;
use yii\widgets\ActiveForm;

$sharedPointSaleModule = $this->getSharedPointSaleModule();
$pointSaleModule = $this->getPointSaleModule();

$this->setTitle('Points de vente partagés');
$this->addBreadcrumb($this->getTitle());
$this->addButton(
    [
        'label' => 'Partager un point de vente <span class="glyphicon glyphicon-plus"></span>',
        'url' => 'shared-point-sale/create',
        'class' => 'btn btn-primary'
    ]
);
?>



<div class="shared-point-sale-index">
    <div class="row">
        <div class="col-md-8">

            <div class="panel panel-default">
                <div class="panel-heading">
                    <h3 class="panel-title">
                        Mes demandes de partages en attente
                    </h3>
                </div>
                <div class="panel-body">
                    <?php if(count($sharedPointsSaleRequestOfMe)): ?>
                    <table class="table table-striped table-bordered">
                        <tbody>
                        <?php foreach($sharedPointsSaleRequestOfMe as $sharedPointSale): ?>
                            <tr>
                                <td>
                                    Vous souhaitez partager votre point de vente <strong><?= Html::encode($sharedPointSale->getPointSale()->getName()); ?></strong>
                                    avec le producteur <strong><?= Html::encode($sharedPointSale->getProducerWithSharing()->getName()); ?></strong>.
                                    <br /><small>Demande de partage effectuée le <?= $sharedPointSale->getCreatedAt()->format('d/m/Y à H:i') ?></small>
                                </td>
                                <td>
                                    <a href="<?= Yii::$app->urlManager->createUrl(['shared-point-sale/decline', 'id' => $sharedPointSale->getId()]) ?>" class="btn btn-default">Annuler</a>
                                </td>
                            </tr>
                        <?php endforeach; ?>
                        </tbody>
                    </table>
                    <?php else: ?>
                        <p><em>Aucun résultat</em></p>
                    <?php endif; ?>
                </div>
            </div>

            <div class="panel panel-default">
                <div class="panel-heading">
                    <h3 class="panel-title">
                        Demandes de partage des autres producteurs
                    </h3>
                </div>
                <div class="panel-body">
                    <?php if(count($sharedPointsSaleRequestOthers)): ?>
                    <table class="table table-striped table-bordered">
                        <tbody>
                        <?php foreach($sharedPointsSaleRequestOthers as $sharedPointSale): ?>
                            <tr>
                                <td>Le producteur <strong><?= Html::encode($sharedPointSale->getPointSale()->getProducer()->getName()); ?></strong>
                                    souhaite partager son point de vente <strong><?= Html::encode($sharedPointSale->getPointSale()->getName()); ?></strong>
                                    avec vous.
                                    <br /><br /><small>Demande de partage effectuée le <?= $sharedPointSale->getCreatedAt()->format('d/m/Y à H:i') ?></small>
                                </td>
                                <td>
                                    <?php $form = ActiveForm::begin([
                                        'enableClientValidation' => false,
                                        'action' => Yii::$app->urlManager->createUrl(['shared-point-sale/confirm', 'id' => $sharedPointSale->getId()])
                                    ]); ?>
                                    <?= $form->field($sharedPointSale, 'id_point_sale_with_sharing')
                                        ->dropDownList($pointSaleModule->getRepository()->populatePointSaleDropdownList())
                                        ->label('Votre point de vente correspondant')
                                        ->hint('Absent de la liste ? <a href="'.Yii::$app->urlManager->createUrl(['point-sale/create']).'">Créer le point de vente</a>'); ?>

                                    <?= Html::submitButton('Confirmer', ['class' => 'btn btn-success', 'name' => 'save']) ?>
                                    <?php ActiveForm::end(); ?>
                                </td>
                                <td>
                                    <br />
                                    <a href="<?= Yii::$app->urlManager->createUrl(['shared-point-sale/decline', 'id' => $sharedPointSale->getId()]) ?>" class="btn btn-danger">
                                        Refuser
                                    </a>
                                </td>
                            </tr>
                        <?php endforeach; ?>
                        </tbody>
                    </table>
                    <?php else: ?>
                        <p><em>Aucun résultat</em></p>
                    <?php endif; ?>
                </div>
            </div>

            <div class="panel panel-default">
                <div class="panel-heading">
                    <h3 class="panel-title">
                        Partages confirmés
                    </h3>
                </div>
                <div class="panel-body">
                    <?php if($sharedPointSaleModule->getResolver()->countPointsSaleShared()): ?>
                        <table id="table-shared-point-sale-confirmed" class="table table-striped table-bordered">
                            <thead>
                            <tr>
                                <td>Point de vente</td>
                                <td>Partagé avec</td>
                                <td></td>
                            </tr>
                            </thead>
                            <tbody>
                            <?php foreach($pointsSaleArray as $pointSale): ?>
                                <?php
                                $pointsSaleSharedWithPointSaleArray = $sharedPointSaleModule->getResolver()->getPointsSaleSharedWithPointSale($pointSale);
                                $countPointsSaleSharedWithPointSale = count($pointsSaleSharedWithPointSaleArray);
                                if($countPointsSaleSharedWithPointSale):?>
                                    <?php foreach($pointsSaleSharedWithPointSaleArray as $key => $pointSaleSharedWithPointSale): ?>
                                        <?php $sharedPointSale = $sharedPointSaleModule->getRepository()->findOneSharedPointsSaleConfirmed(
                                            $pointSaleSharedWithPointSale,
                                            GlobalParam::getCurrentProducer()
                                        ); ?>
                                        <tr>
                                            <?php if($key === array_key_first($pointsSaleSharedWithPointSaleArray)): ?>
                                                <td rowspan="<?= $countPointsSaleSharedWithPointSale ?>">
                                                    <?= Html::encode($pointSale->getName()); ?><br />
                                                    <span class="badge">
                                                        <?= $countPointsSaleSharedWithPointSale ?>
                                                    </span>
                                                </td>
                                            <?php endif; ?>
                                            <td>
                                                <div class="shared-point-sale-confirmed">
                                                    <?= Html::encode($pointSaleSharedWithPointSale->getProducer()->getName()); ?>
                                                    - <?= Html::encode($pointSaleSharedWithPointSale->getName()); ?>
                                                    <br /><small>
                                                    <?php if($sharedPointSale):?>
                                                        Depuis le <?= $sharedPointSale->getConfirmedAt()->format('d/m/Y') ?>
                                                    <?php else: ?>
                                                         Partage hérité
                                                    <?php endif; ?>
                                                    </small>
                                                </div>
                                            </td>
                                            <td>
                                                <?php if($sharedPointSale):?>
                                                    <a href="<?= Yii::$app->urlManager->createUrl(['shared-point-sale/decline', 'id' => $sharedPointSale->id]) ?>" class="btn btn-xs btn-default" title="Annuler">
                                                        <span class="glyphicon glyphicon-remove"></span>
                                                    </a>
                                                <?php endif; ?>
                                            </td>
                                        </tr>
                                    <?php endforeach; ?>
                                <?php endif; ?>
                            <?php endforeach; ?>
                            </tbody>
                        </table>
                    <?php else: ?>
                        <p><em>Aucun résultat</em></p>
                    <?php endif; ?>
                </div>
            </div>
        </div>
        <div class="col-md-4">
            <div class="callout callout-info">
                <span class="glyphicon glyphicon-info-sign"></span>
                Cette fonctionnalité vous permet de partager des points de vente avec d'autres producteurs inscrits sur Souke
                et avec qui vous avez des distributions en commun.<br />
                Quand vous partagez un point de vente avec un autre producteur, un lien vers votre boutique est
                proposé aux clients de ce producteur quand ils passent commande sur le point de vente partagé.
            </div>
        </div>
    </div>
</div>
