<?php
/**
 * Copyright Guillaume Bourgeois (2018)
 *
 * contact@souke.fr
 *
 * Ce logiciel est un programme informatique servant à aider les producteurs
 * à distribuer leur production en circuits courts.
 *
 * Ce logiciel est régi par la licence CeCILL soumise au droit français et
 * respectant les principes de diffusion des logiciels libres. Vous pouvez
 * utiliser, modifier et/ou redistribuer ce programme sous les conditions
 * de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA
 * sur le site "http://www.cecill.info".
 *
 * En contrepartie de l'accessibilité au code source et des droits de copie,
 * de modification et de redistribution accordés par cette licence, il n'est
 * offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,
 * seule une responsabilité restreinte pèse sur l'auteur du programme,  le
 * titulaire des droits patrimoniaux et les concédants successifs.
 *
 * A cet égard  l'attention de l'utilisateur est attirée sur les risques
 * associés au chargement,  à l'utilisation,  à la modification et/ou au
 * développement et à la reproduction du logiciel par l'utilisateur étant
 * donné sa spécificité de logiciel libre, qui peut le rendre complexe à
 * manipuler et qui le réserve donc à des développeurs et des professionnels
 * avertis possédant  des  connaissances  informatiques approfondies.  Les
 * utilisateurs sont donc invités à charger  et  tester  l'adéquation  du
 * logiciel à leurs besoins dans des conditions permettant d'assurer la
 * sécurité de leurs systèmes et ou de leurs données et, plus généralement,
 * à l'utiliser et l'exploiter dans les mêmes conditions de sécurité.
 *
 * Le fait que vous puissiez accéder à cet en-tête signifie que vous avez
 * pris connaissance de la licence CeCILL, et que vous en avez accepté les
 * termes.
 */

namespace common\components;

use common\helpers\Password;
use GuzzleHttp\Client;
use domain\Producer\Producer\Producer;
use yii\base\ErrorException;

class AlwaysdataClient
{
    public function initRedirections(Producer $producer)
    {
        $this->createProducerSiteShortUrlRedirection($producer);
        $this->createProducerEmailRedirection($producer);
    }

    public function createProducerEmailRedirection(Producer $producer)
    {
        return $this->post('mailbox',[
            'domain' => \Yii::$app->parameterBag->get('alwaysdataDomainId'),
            'name' => $producer->slug,
            'password' => Password::generate(13),
            'redirect_enabled' => true,
            'redirect_to' => $producer->contact_email
        ]);
    }

    public function createProducerSiteShortUrlRedirection(Producer $producer)
    {
        return $this->post('site', [
            'addresses' => [$producer->slug.'.souke.fr'],
            'type' => 'redirect',
            'url' => 'https://producteurs.souke.fr/'.$producer->slug,
            'redirect_type' => 'PERMANENT',
            'annotation' => 'Souke / '.$producer->name
        ]);
    }

    private function post(string $resource, array $data)
    {
        $client = $this->getClient($resource);

        return $client->request('POST', '', [
            'body' => json_encode($data)
        ]);
    }

    private function getClient(string $resource)
    {
        $this->checkConfiguration();

        return new Client([
            'base_uri' => \Yii::$app->parameterBag->get('alwaysdataApiUrl').$resource.'/',
            'auth' => [\Yii::$app->parameterBag->get('alwaysdataApiKey').' account='.\Yii::$app->parameterBag->get('alwaysdataAccount'), ''],
        ]);
    }

    private function checkConfiguration()
    {
        if(!\Yii::$app->parameterBag->has('alwaysdataApiUrl')
            || !\Yii::$app->parameterBag->has('alwaysdataAccount')
            || !\Yii::$app->parameterBag->has('alwaysdataApiKey')
            || !\Yii::$app->parameterBag->has('alwaysdataDomainId')) {

            throw new ErrorException('Configuration API Alwaysdata absente ou incomplète dans params-local.php');
        }
    }
}