<?php
/**
 * Copyright Guillaume Bourgeois (2018)
 *
 * contact@souke.fr
 *
 * Ce logiciel est un programme informatique servant à aider les producteurs
 * à distribuer leur production en circuits courts.
 *
 * Ce logiciel est régi par la licence CeCILL soumise au droit français et
 * respectant les principes de diffusion des logiciels libres. Vous pouvez
 * utiliser, modifier et/ou redistribuer ce programme sous les conditions
 * de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA
 * sur le site "http://www.cecill.info".
 *
 * En contrepartie de l'accessibilité au code source et des droits de copie,
 * de modification et de redistribution accordés par cette licence, il n'est
 * offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,
 * seule une responsabilité restreinte pèse sur l'auteur du programme,  le
 * titulaire des droits patrimoniaux et les concédants successifs.
 *
 * A cet égard  l'attention de l'utilisateur est attirée sur les risques
 * associés au chargement,  à l'utilisation,  à la modification et/ou au
 * développement et à la reproduction du logiciel par l'utilisateur étant
 * donné sa spécificité de logiciel libre, qui peut le rendre complexe à
 * manipuler et qui le réserve donc à des développeurs et des professionnels
 * avertis possédant  des  connaissances  informatiques approfondies.  Les
 * utilisateurs sont donc invités à charger  et  tester  l'adéquation  du
 * logiciel à leurs besoins dans des conditions permettant d'assurer la
 * sécurité de leurs systèmes et ou de leurs données et, plus généralement,
 * à l'utiliser et l'exploiter dans les mêmes conditions de sécurité.
 *
 * Le fait que vous puissiez accéder à cet en-tête signifie que vous avez
 * pris connaissance de la licence CeCILL, et que vous en avez accepté les
 * termes.
 */

namespace common\components;

use domain\Producer\Producer\Producer;
use yii\base\ErrorException;

class BusinessLogic
{
    protected ?Producer $producerContext = null;

    use BusinessLogicTrait;

    public function getModules()
    {
        return [
            $this->getSettingModule(),
            $this->getFeatureModule(),
            $this->getFeatureProducerModule(),
            $this->getUnitModule(),
            $this->getTaxRateModule(),
            $this->getUserUserGroupModule(),
            $this->getUserGroupModule(),
            $this->getPaymentModule(),
            $this->getProducerPriceRangeModule(),
            $this->getUserProducerModule(),
            $this->getUserPointSaleModule(),
            $this->getUserModule(),
            $this->getEmailModule(),
            $this->getAutomaticEmailModule(),
            $this->getUserMessageModule(),
            $this->getPointSaleDistributionModule(),
            $this->getProductAccessoryModule(),
            $this->getAccessoryModule(),
            $this->getProductDistributionModule(),
            $this->getProductCategoryModule(),
            $this->getProductPointSaleModule(),
            $this->getProductPriceModule(),
            $this->getProductSubscriptionModule(),
            $this->getTicketUserModule(),
            $this->getTicketMessageModule(),
            $this->getTicketModule(),
            $this->getPointSaleModule(),
            $this->getSharedPointSaleModule(),
            $this->getProductModule(),
            $this->getProductOrderModule(),
            $this->getOrderStatusModule(),
            $this->getOrderStatusHistoryModule(),
            $this->getQuotationModule(),
            $this->getInvoiceModule(),
            $this->getDeliveryNoteModule(),
            $this->getDocumentModule(),
            $this->getSubscriptionModule(),
            $this->getDistributionModule(),
            $this->getProducerModule(),
            $this->getOrderModule(),
        ];
    }

    public function getProducerContext(): ?Producer
    {
        return $this->producerContext;
    }

    public function setProducerContext(Producer $producer = null)
    {
        $this->producerContext = $producer;

        foreach($this->getModules() as $module) {
            foreach($module->getServices() as $serviceClass) {
                $instanceService = $serviceClass::getInstance();
                $instanceService->setProducerContext($producer);
            }
        }
    }

    /*
     * Hiérarchie des apps
     */

    public function getModuleLevelHierarchyByService($serviceClass): int
    {
        $modulesArray = $this->getModules();
        $entityFqcnService = $this->getEntityFqcnByService($serviceClass);

        foreach($modulesArray as $key => $module) {
            if($module->getEntityFqcn() == $entityFqcnService) {
                return $key;
            }
        }
    }

    public function getEntityFqcnByService(string $serviceClass): string
    {
        $modulesArray = $this->getModules();

        foreach($modulesArray as $module) {
            if(in_array($serviceClass, $module->getServices())) {
                return $module->getEntityFqcn();
            }
        }

        throw new ErrorException('Service '.$serviceClass.' introuvable dans les modules.');
    }
}