<?php
/**
Copyright Guillaume Bourgeois (2018)

contact@souke.fr

Ce logiciel est un programme informatique servant à aider les producteurs
à distribuer leur production en circuits courts.

Ce logiciel est régi par la licence CeCILL soumise au droit français et
respectant les principes de diffusion des logiciels libres. Vous pouvez
utiliser, modifier et/ou redistribuer ce programme sous les conditions
de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA
sur le site "http://www.cecill.info".

En contrepartie de l'accessibilité au code source et des droits de copie,
de modification et de redistribution accordés par cette licence, il n'est
offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,
seule une responsabilité restreinte pèse sur l'auteur du programme,  le
titulaire des droits patrimoniaux et les concédants successifs.

A cet égard  l'attention de l'utilisateur est attirée sur les risques
associés au chargement,  à l'utilisation,  à la modification et/ou au
développement et à la reproduction du logiciel par l'utilisateur étant
donné sa spécificité de logiciel libre, qui peut le rendre complexe à
manipuler et qui le réserve donc à des développeurs et des professionnels
avertis possédant  des  connaissances  informatiques approfondies.  Les
utilisateurs sont donc invités à charger  et  tester  l'adéquation  du
logiciel à leurs besoins dans des conditions permettant d'assurer la
sécurité de leurs systèmes et ou de leurs données et, plus généralement,
à l'utiliser et l'exploiter dans les mêmes conditions de sécurité.

Le fait que vous puissiez accéder à cet en-tête signifie que vous avez
pris connaissance de la licence CeCILL, et que vous en avez accepté les
termes.
 */

namespace domain\Setting\SettingDetails\Admin;

use domain\Setting\SettingDefinition;
use domain\Setting\SettingDetails\Admin\AlertMessage\AdminAlertMessageIconSetting;
use domain\Setting\SettingDetails\Admin\AlertMessage\AdminAlertMessageSetting;
use domain\Setting\SettingDetails\Admin\AlertMessage\AdminAlertMessageTitleSetting;
use domain\Setting\SettingDetails\Admin\AlertMessage\AdminAlertMessageTypeSetting;
use domain\Setting\SettingDetails\Admin\AlertMessage\AdminAlertMessageUpdatedAtSetting;
use domain\Setting\SettingDetails\Admin\AlertMessage\AdminSupportAlertMessageDisplaySetting;
use domain\Setting\SettingDetails\Admin\AlertMessage\AdminSupportAlertMessageIconSetting;
use domain\Setting\SettingDetails\Admin\AlertMessage\AdminSupportAlertMessageSetting;
use domain\Setting\SettingDetails\Admin\AlertMessage\AdminSupportAlertMessageTitleSetting;
use domain\Setting\SettingDetails\Admin\AlertMessage\AdminSupportAlertMessageTypeSetting;
use domain\Setting\SettingDetails\Admin\General\AdministratorEmailAdminSetting;
use domain\Setting\SettingDetails\Admin\General\AdministratorPhoneNumberAdminSetting;
use domain\Setting\SettingDetails\Admin\General\BulkMailerAdminSetting;
use domain\Setting\SettingDetails\Admin\General\ForumFlarumUrlAdminSetting;
use domain\Setting\SettingDetails\Admin\General\MailerAdminSetting;
use domain\Setting\SettingDetails\Admin\General\MaximumNumberProducersAdminSetting;
use domain\Setting\SettingDetails\Admin\General\SupportOnlineAdminSetting;
use domain\Setting\SettingDetails\Admin\AlertMessage\AdminAlertMessageDisplaySetting;

class AdminSettingDefinition extends SettingDefinition
{
    const SECTION_GENERAL = 'general';
    const SUBSECTION_GENERAL = 'general.main';

    const SECTION_ALERT_MESSAGE = 'alertmessage';
    const SUBSECTION_ALERT_MESSAGE_GLOBAL = 'alertmessage.global';
    const SUBSECTION_ALERT_MESSAGE_SUPPORT = 'alertmessage.support';

    public function getSettingDetails(): array
    {
        return [
            self::SECTION_GENERAL => [
                self::SUBSECTION_GENERAL => [
                    new SupportOnlineAdminSetting(),
                    new AdministratorEmailAdminSetting(),
                    new AdministratorPhoneNumberAdminSetting(),
                    new MaximumNumberProducersAdminSetting(),
                    new ForumFlarumUrlAdminSetting(),
                    new MailerAdminSetting(),
                    new BulkMailerAdminSetting(),
                ]
            ],
            self::SECTION_ALERT_MESSAGE => [
                self::SUBSECTION_ALERT_MESSAGE_GLOBAL => [
                    new AdminAlertMessageDisplaySetting(),
                    new AdminAlertMessageTypeSetting(),
                    new AdminAlertMessageIconSetting(),
                    new AdminAlertMessageTitleSetting(),
                    new AdminAlertMessageSetting(),
                    new AdminAlertMessageUpdatedAtSetting(),
                ],
                self::SUBSECTION_ALERT_MESSAGE_SUPPORT => [
                    new AdminSupportAlertMessageDisplaySetting(),
                    new AdminSupportAlertMessageTypeSetting(),
                    new AdminSupportAlertMessageIconSetting(),
                    new AdminSupportAlertMessageTitleSetting(),
                    new AdminSupportAlertMessageSetting(),
                ],
            ]
        ];
    }

    public function getSectionLabels(): array
    {
        return [
            self::SECTION_GENERAL => 'General',
            self::SUBSECTION_GENERAL => 'General',

            self::SECTION_ALERT_MESSAGE => 'Message d\'alerte',
            self::SUBSECTION_ALERT_MESSAGE_GLOBAL => 'Global',
            self::SUBSECTION_ALERT_MESSAGE_SUPPORT => 'Support'
        ];
    }

    public function getSectionsArray(): array
    {
        $sectionsArray = [];

        foreach($this->getSettingDetails() as $sectionName => $subsectionsArray) {
            $sectionsArray[] = [
                'name' => $sectionName,
                'nameDisplay' => $this->getSectionLabelBySectionName($sectionName),
            ];
        }

        return $sectionsArray;
    }

    public function getSettingDetailsFlat(): array
    {
        $settingDetailsFlatArray = [];

        foreach($this->getSettingDetails() as $sectionsArray) {
            foreach($sectionsArray as $subsectionsArray) {
                foreach($subsectionsArray as $settingDetail) {
                    $settingDetailsFlatArray[] = $settingDetail;
                }
            }
        }

        return $settingDetailsFlatArray;
    }

    public function getSectionLabelBySectionName(string $sectionName): string
    {
        return $this->getSectionLabels()[$sectionName];
    }
}